@@ -11,7 +11,7 @@
 #include <glade/glade.h>
 #include <X11/Xatom.h>
 
-#include "theme-common.h"
+#include "gnome-theme-info.h"
 #include "wm-common.h"
 #include "capplet-util.h"
 #include "eggcellrendererkeys.h"
@@ -523,6 +523,31 @@ key_theme_changed (GConfClient *client,
 }
 
 
+static gboolean
+cb_check_for_uniqueness (GtkTreeModel *model,
+			 GtkTreePath  *path,
+			 GtkTreeIter  *iter,
+			 gpointer      user_data)
+{
+  KeyEntry *key_entry;
+  KeyEntry *tmp_key_entry;
+
+  key_entry = (KeyEntry *)user_data;
+  gtk_tree_model_get (key_entry->model, iter,
+		      KEYENTRY_COLUMN, &tmp_key_entry,
+		      -1);
+
+  if (tmp_key_entry != NULL &&
+      key_entry->keyval == tmp_key_entry->keyval &&
+      key_entry->mask   == tmp_key_entry->mask)
+    {
+      key_entry->editable = FALSE;
+      key_entry->gconf_key = tmp_key_entry->gconf_key;
+      return TRUE;
+    }
+  return FALSE;
+}
+
 static void
 accel_edited_callback (GtkCellRendererText *cell,
                        const char          *path_string,
@@ -535,7 +560,7 @@ accel_edited_callback (GtkCellRendererText *cell,
   GtkTreeModel *model;
   GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
   GtkTreeIter iter;
-  KeyEntry *key_entry;
+  KeyEntry *key_entry, tmp_key;
   GError *err = NULL;
   char *str;
 
@@ -547,7 +572,34 @@ accel_edited_callback (GtkCellRendererText *cell,
 
   /* sanity check */
   if (key_entry == NULL)
+    {
+      gtk_tree_path_free (path);
+      return;
+    }
+
+  tmp_key.model  = model;
+  tmp_key.keyval = keyval;
+  tmp_key.mask   = mask;
+  tmp_key.editable = TRUE; /* kludge to stuff in a return flag */
+  gtk_tree_model_foreach (model, cb_check_for_uniqueness, &tmp_key);
+
+  /* flag to see if the new accelerator was in use by something */
+  if (!tmp_key.editable)
+    {
+      GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (view))),
+				       GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
+				       GTK_MESSAGE_WARNING,
+				       GTK_BUTTONS_OK,
+				       _("That accelerator key is already in use by: %s\n"),
+				       key_entry->gconf_key);
+      gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
+
+      egg_cell_renderer_keys_set_accelerator (EGG_CELL_RENDERER_KEYS (cell),
+					      key_entry->keyval, key_entry->mask);
+      gtk_tree_path_free (path);
     return;
+    }
 
   str = binding_name (keyval, mask, FALSE);
 
@@ -591,13 +643,13 @@ theme_changed_func (gpointer  uri,
   GList *list;
 
   client = gconf_client_get_default ();
-  key_theme_list = theme_common_get_list ();
+  key_theme_list = gnome_theme_info_find_by_type (GNOME_THEME_GTK_2_KEYBINDING);
 
   omenu = WID ("key_theme_omenu");
   menu = gtk_menu_new ();
   for (list = key_theme_list; list; list = list->next)
     {
-      ThemeInfo *info = list->data;
+      GnomeThemeInfo *info = list->data;
 
       if (! info->has_keybinding)
 	continue;
@@ -699,11 +751,11 @@ setup_dialog (GladeXML *dialog)
 
   client = gconf_client_get_default ();
 
-  key_theme_list = theme_common_get_list ();
+  key_theme_list = gnome_theme_info_find_by_type (GNOME_THEME_GTK_2_KEYBINDING);
 
   for (list = key_theme_list; list; list = list->next)
     {
-      ThemeInfo *info = list->data;
+      GnomeThemeInfo *info = list->data;
       if (info->has_keybinding)
 	{
 	  found_keys = TRUE;
@@ -725,7 +777,7 @@ setup_dialog (GladeXML *dialog)
   else
     {
       theme_changed_func (NULL, dialog);
-      theme_common_register_theme_change ((GFunc) theme_changed_func, dialog);
+      gnome_theme_info_register_theme_change ((GFunc) theme_changed_func, dialog);
       gconf_client_add_dir (client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
       gconf_client_notify_add (client,
 			       KEY_THEME_KEY,
