@@ -41,7 +41,6 @@
 #include "gnome-settings-keyboard.h"
 #include "gnome-settings-background.h"
 #include "gnome-settings-sound.h"
-#include "gnome-settings-wm.h"
 #include "gnome-settings-accessibility-keyboard.h"
 #include "gnome-settings-screensaver.h"
 #include "gnome-settings-default-editor.h"
@@ -236,7 +235,6 @@ gnome_settings_daemon_new (void)
   gnome_settings_mouse_init (client);
   gnome_settings_keyboard_init (client);
   gnome_settings_sound_init (client);
-  gnome_settings_wm_init (client);
   gnome_settings_accessibility_keyboard_init (client);
   gnome_settings_screensaver_init (client);
   gnome_settings_default_editor_init (client);
@@ -277,7 +275,6 @@ gnome_settings_daemon_new (void)
   gnome_settings_mouse_load (client);
   gnome_settings_keyboard_load (client);
   gnome_settings_sound_load (client);
-  gnome_settings_wm_load (client);
   gnome_settings_accessibility_keyboard_load (client);
   gnome_settings_screensaver_load (client);
   gnome_settings_default_editor_load (client);
